import asyncio
from .function05 import Configs
from ..exceptions import Qbitorcancel
from ..exceptions import Qbitskipselection
#==================================================================================

class TEngine:

    async def get01(cli, hid):
        moonus = cli.torrents_info(torrent_hashes=hid)[0]
        return moonus

#==================================================================================

    async def get02(imog, cli, cid, hid):
        while True: #WAIT_FOR_METADATA
            if cid not in Configs.DATA06:
                raise Qbitorcancel(None)
            await asyncio.sleep(1)
            files = cli.torrents_files(torrent_hash=hid)
            if files:
                if len(files) > 1: cli.torrents_pause(torrent_hashes=hid)
                return files

#==================================================================================

    async def get03(cid):
        Configs.DATA07.append(cid)
        while True:
            await asyncio.sleep(1)
            if cid not in Configs.DATA06:
                raise Qbitorcancel(None)
            #if cid not in Configs.DATA07:
                #raise Qbitskipselection(None)
            if cid not in Configs.DATA07:
                break

#==================================================================================



from .function05 import Configs

class Cleans:

    async def get01(cid):
        try: Configs.DATA06.remove(cid) if cid in Configs.DATA06 else None
        except Exception: pass

    async def get02(cid):
        try: Configs.DATA07.remove(cid) if cid in Configs.DATA07 else None
        except Exception: pass



import os
import shutil
#=====================================================================================================

class Cleand:

    async def get01(dlocation):
        try: shutil.rmtree(dlocation)
        except Exception: pass

    async def get02(imog, thumbnail, flocation):
        try: await imog.delete()
        except Exception: pass
        try: os.remove(flocation)
        except Exception: pass
        try: os.remove(thumbnail)
        except Exception: pass

#=====================================================================================================

    async def get03(cli, hid, dfiles=True):
        try: cli.torrents_delete(torrent_hashes=hid, delete_files=dfiles)
        except Exception: pass

    async def get04(cli, hid, dfiles=False):
        try: cli.torrents_delete(torrent_hashes=hid, delete_files=dfiles)
        except Exception: pass

    async def get05(cli, gid):
        try: dow = cli.get_download(gid)
        except Exception: dow = None
        try: cli.remove(downloads=[dow], force=True, files=True, clean=True) if dow else None
        except Exception: pass

    #=================================================================================================




class Qbitskipselection(Exception):
    pass

class Aria2pcancel(Exception):
    pass

class Aria2perrors(Exception):
    pass

class Qbitorerrors(Exception):
    pass

class Qbitorcancel(Exception):
    pass
